use std::borrow::BorrowMut;

use egui::{Button, Color32, Label, RichText, Sense};

use super::ComponentUi;



pub struct SideNav;

impl ComponentUi for SideNav {
    fn ui(gui: &mut crate::ui::gui::Gui, ui: &mut egui::Ui) {
        let mut playlist_names = gui.manifest
            .get_playlists()
            .keys().cloned().collect::<Vec<String>>();

        playlist_names.sort_by_key(|name| name.to_lowercase());
        ui.with_layout(egui::Layout::top_down(egui::Align::TOP), |ui| {
            
            for pname in playlist_names {
                if gui.current_playlist.is_empty() {
                    gui.current_playlist = pname.to_string();
                }
                ui.horizontal(|ui| {

                    let tint = Color32::from_hex("#333377").unwrap();
                    ui.add(egui::Image::new(crate::data::NOTE_ICON).tint(tint));
                    ui.horizontal(|ui| {
                        let text;
                        if gui.current_playlist == *pname {
                            text = RichText::new(&pname).color(tint);
                        } else {
                            text = RichText::new(&pname);
                        }
                        let button = Label::new(text).sense(Sense::click());
                        if ui.add(button).clicked() {
                            gui.current_playlist = pname.to_string();
                        }
                    });
                });
            } 
        });
    }
    // #333377
}
