use egui::Color32;
use egui_extras::{Column, TableBuilder};

use crate::manifest::song::SongType;

use super::{context_menu::ContextMenu, search_bar::SearchType, ComponentUi};

#[derive(Debug, Default)]
pub struct SongList {
}

impl ComponentUi for SongList {
    fn ui(gui: &mut crate::ui::gui::Gui, ui: &mut egui::Ui) {
        ui.vertical(|ui| {
            {
                use crate::ui::gui::components::ComponentUiMut;
                let mut search = gui.search.clone();
                search.ui(gui, ui);
                gui.search = search;
            }
            
            ui.vertical(|ui| {
                let available_height = ui.available_height();
                let table = TableBuilder::new(ui)
                    .striped(true)
                    .cell_layout(egui::Layout::left_to_right(egui::Align::Center))
                    .resizable(true)
                    //.column(Column::auto())
                    //.column(Column::auto())
                    //.column(
                    //    Column::remainder()
                    //        .at_least(40.0)
                    //        .clip(true)
                    //        .resizable(true),
                    //)
                    .column(Column::auto())
                    .column(Column::remainder())
                    //.column(Column::remainder())
                    .min_scrolled_height(0.0)
                    .max_scroll_height(available_height)
                    .sense(egui::Sense::click());
                
                let playlists = gui.manifest.get_playlists().clone();

                let songs = {
                    let mut songs = Vec::new();
                    for (pname, p) in playlists {
                        for (sname, s) in p {
                            songs.push((pname.clone(), sname, s));
                        }
                    }
                    
                    songs.sort_by_key(|song| song.1.to_lowercase());
                    songs
                };

                table.header(20.0, |mut header| {
                    // header.col(|_|{});
                    //header.col(|ui| {
                    //    ui.strong("Playlist");vec.sort_by_key(|name| name.to_lowercase());
                    //}); 
                    header.col(|ui| { 
                        ui.strong("Source");
                    });
                    header.col(|ui| {
                        ui.strong("Name");
                    });
                }).body(|mut body| {
                    for (pname, sname, s) in songs {
                        if pname != gui.current_playlist {
                            continue;
                        }
                        match gui.search.get_search() {
                            (SearchType::Generic, filter) if !filter.is_empty() => {
                                if !pname.to_lowercase().contains(&filter) {
                                    continue;
                                }
                            }
                            (SearchType::Song, filter) if !filter.is_empty() => {
                                if !sname.to_lowercase().contains(&filter) {
                                    continue;
                                }
                            }
                            (SearchType::Source, filter) if !filter.is_empty() => {
                                if !s.get_type().to_string().to_lowercase().contains(&filter) {
                                    continue;
                                }
                            }
                            (SearchType::Url, filter) if !filter.is_empty() => {
                                if !s.get_url_str().contains(&filter) {
                                    continue;
                                }
                            }
                            (SearchType::Source, _) => (),
                            (SearchType::Song, _) => (),
                            (SearchType::Generic, _) => (),
                            (SearchType::Url, _) => (),
                        }
                        body.row(18.0, |mut row| {
                             
                            //row.col(|ui| {
                            //    ui.label(pname.clone())
                            //        .context_menu(|ui| ContextMenu::ui(gui, ui, &pname, &sname, &s));
                            //});
                            row.col(|ui| {
                                let color =
                                match s.get_type() {
                                    SongType::Youtube => Color32::from_hex("#FF0000").unwrap(),
                                    SongType::Spotify => Color32::from_hex("#1db954").unwrap(),
                                    SongType::Soundcloud => Color32::from_hex("#F26F23").unwrap()
                                };

                                ui.colored_label(color, s.get_type().to_string())
                                    .context_menu(|ui| ContextMenu::ui(gui, ui, &pname, &sname, &s));
                            });
                            row.col(|ui| {
                                ui.hyperlink_to(sname.clone(), s.get_url_str())
                                    .context_menu(|ui| ContextMenu::ui(gui, ui, &pname, &sname, &s));
                            });

                            row.response()
                                .context_menu(|ui| ContextMenu::ui(gui, ui, &pname, &sname, &s));

                        });
                    }
                });
            });
        });
    }
}
